module Locomotive
  class PagesController < BaseController

    account_required & within_site

    localized

    before_filter :back_to_default_site_locale, only: %w(new create)

    before_filter :load_page, only: [:show, :edit, :update, :sort, :destroy]

    layout 'locomotive/layouts/preview', only: [:edit]

    respond_to :json, only: [:sort]

    def index
      authorize Page
      @pages = current_site.all_pages_in_once
      respond_with(@pages)
    end

    def show
      authorize @page
      respond_with @page
    end

    def new
      authorize Page
      @page = current_site.pages.build
      respond_with @page
    end

    def create
      authorize Page
      @page = current_site.pages.create(page_params)
      respond_with @page, location: -> { edit_page_path(current_site, @page) }
    end

    def edit
      authorize @page
      respond_with @page
    end

    def update
      authorize @page
      @page.update_attributes(page_params)
      respond_with @page, location: edit_page_path(current_site, @page)
    end

    def destroy
      authorize @page
      @page.destroy
      respond_with @page, location: pages_path(current_site)
    end

    def sort
      authorize @page, :update?
      @page.sort_children!(params.require(:children))
      respond_with @page, location: edit_page_path(current_site, @page)
    end

    private

    def load_page
      @page = current_site.pages.find(params[:id])
    end

    def page_params
      params.require(:page).permit(:title, :slug, :published, :parent, :parent_id, :raw_template)
    end

  end
end
